@@ -1,5 +1,9 @@
 # -*- coding: utf-8 -*-
 
+"""This module provides high-level classes to open and read DarwinCore Archive (DwC-A) files.
+
+"""
+
 import os
 from tempfile import mkdtemp
 from zipfile import ZipFile
@@ -17,22 +21,38 @@ class DwCAReader(object):
     
     """This class is used to represent a Darwin Core Archive as a whole.
 
-    It gives read access to the (Core file) rows, to the Archive metadata, ...
+    It gives read access to the contained data, to the scientific metadata, ...
+
+    :param path: path to the Darwin Core Archive (either a zip file or a directory) to open.
+    :type path: str
 
     A short usage example::
 
         from dwca import DwCAReader
+        
+        dwca = DwCAReader('my_archive.zip')
+        # Iterating on core rows is easy:
+        for core_row in dwca:
+            # core_row is an instance of rows.CoreRow
+            print core_row
 
-        # The with statement is recommended as it ensures resources will be properly cleaned after
-        # usage:
-        with DwCAReader('my_archive.zip') as dwca:
-            # Iterating on core rows is easy:
-            for core_row in dwca:
-                # core_row is an instance of rows.CoreRow
-                print core_row
+        # Scientific metadata (EML) is available as a BeautifulSoup object
+        print dwca.metadata.prettify()
 
-            # Scientific metadata (EML) is available as a BeautifulSoup object
-            print dwca.metadata.prettify()
+        # Close the archive to free resources
+        dwca.close()
+
+    The archive can also be opened with the `with` statement. This is recommended, since it ensures
+    resources will be properly cleaned after usage:
+
+    ::
+
+        from dwca import DwCAReader
+
+        with DwCAReader('my-archive.zip') as dwca:
+            pass  # Do what you want
+
+        # When leaving the block, resources are automatically freed.
 
     """
 
@@ -45,34 +65,45 @@ class DwCAReader(object):
     def __init__(self, path):
         """Open the file, reads all metadata and store it in self.metadata (BeautifulSoup obj.)
         Also already open the core file so we've a file descriptor for further access.
-
-        :param path: path to the Darwin Core Archive file to open.
         """
-        #:
+        #: The path to the Darwin Core Archive file, as passed to the constructor.
         self.archive_path = path
 
-        self._unzipped_folder_path = self._unzip()
+        if os.path.isdir(self.archive_path):  # Archive as a directly readable directory
+            self._workin_directory_path = self.archive_path
+            self._workin_directory_cleanable = False
+        else:  # Archive is zipped, we have to unzip it
+            self._workin_directory_path = self._unzip()
+            self._workin_directory_cleanable = True
         
-        #: An ArchiveDescriptor instance representing the archive descriptor (``meta.xml``)
+        #: An :class:`descriptors.ArchiveDescriptor` instance giving access to the archive descriptor (``meta.xml``)
         self.descriptor = ArchiveDescriptor(self._read_additional_file('meta.xml'))
 
-        # Load the (scientific) metadata file and store its representation in an attribute
-        #:
+        #: A :class:`BeautifulSoup` instance containing the (scientific) metadata of the archive.
         self.metadata = self._parse_metadata_file()
         #:
         self.source_metadata = None
 
         self._corefile = _EmbeddedCSV(self.descriptor.core,
-                                      self._unzipped_folder_path)
+                                      self._workin_directory_path)
 
     @property
     #TODO: decide, test and document what we guarantee about ordering
     def rows(self):
-        """Return all rows from the core file as a list of :class:`rows.CoreRow` instances."""
+        """A list of :class:`rows.CoreRow` instances representing the content of the archive.
+
+        .. warning::
+
+            This will cause all rows to be loaded in memory. In case of large Darwin Core Archive,
+            you may prefer iterating with a for loop.
+        """
         return list(self)
 
     def get_row_by_id(self, row_id):
-        """Return the (Core) row whose id is row_id. Raise RowNotFound if no match.
+        """Return the (core) row whose id is row_id.
+
+        :returns:  :class:`dwca.rows.CoreRow` -- the matching row.
+        :raises: :class:`dwca.exceptions.RowNotFound`
 
         .. warning::
 
@@ -90,7 +121,10 @@ class DwCAReader(object):
             raise RowNotFound
 
     def get_row_by_index(self, index):
-        """Return a core row according to its index in core file. Raise RowNotFound if no match.
+        """Return a core row according to its position/index in core file.
+
+        :returns:  :class:`dwca.rows.CoreRow` -- the matching row.
+        :raises: :class:`dwca.exceptions.RowNotFound`
 
         .. note::
 
@@ -115,17 +149,13 @@ class DwCAReader(object):
             - File existence is not tested.
 
         """
-        return os.path.abspath(os.path.join(self._unzipped_folder_path, relative_path))
+        return os.path.abspath(os.path.join(self._workin_directory_path, relative_path))
 
     def _read_additional_file(self, relative_path):
         """Read an additional file in the archive and return its content."""
         p = self.absolute_temporary_path(relative_path)
         return open(p).read()
 
-    @staticmethod
-    def _create_temporary_folder():
-        return mkdtemp()[1]
-
     def _parse_metadata_file(self):
         """Load the archive (scientific) Metadata file, parse it with
         BeautifulSoup and return its content."""
@@ -139,7 +169,7 @@ class DwCAReader(object):
 
     def _unzip(self):
         """Unzip the current archive in a temporary directory and return its path."""
-        unzipped_folder = self._create_temporary_folder()
+        unzipped_folder = mkdtemp()[1]  # Creating a temporary folder
         #TODO: check content of file!!!! It may, for example contains
         #absolute path (see zipfile doc)
         ZipFile(self.archive_path, 'r').extractall(unzipped_folder)
@@ -150,13 +180,14 @@ class DwCAReader(object):
 
         .. note::
             - Alternatively, :class:`.DwCAReader` can be instanciated using the `with` statement.\
-            Cleanup will then be automatically performed when leaving the block.
+            (see example above).
 
         """
-        self._cleanup_temporary_folder()
+        if self._workin_directory_cleanable:
+            self._cleanup_temporary_folder()
 
     def _cleanup_temporary_folder(self):
-        rmtree(self._unzipped_folder_path, False)
+        rmtree(self._workin_directory_path, False)
 
     def core_contains_term(self, term_url):
         """Return True if the Core file of the archive contains the term_url term."""
@@ -170,7 +201,7 @@ class DwCAReader(object):
         cl = self._corefile.get_row_by_index(self._corefile_pointer)
         if cl:
             self._corefile_pointer = self._corefile_pointer + 1
-            return CoreRow(cl, self.descriptor, self._unzipped_folder_path,
+            return CoreRow(cl, self.descriptor, self._workin_directory_path,
                            self.source_metadata)
         else:
             raise StopIteration
@@ -178,12 +209,12 @@ class DwCAReader(object):
 
 class GBIFResultsReader(DwCAReader):
     
-    """This class is used to represent the (slightly augmented) variant of Darwin Core Archive
+    """This class is used to represent the slightly augmented variant of Darwin Core Archive
     produced by the new GBIF Data Portal when exporting occurrences.
 
 
-    It is a subclass of :class:`.DwCAReader` and provides a few more features that reflect the
-    additional data provided in these specific archives:
+    It provides a few additions to :class:`.DwCAReader` that reflect the additional data provided
+    in these specific archives:
 
         - The content of `citations.txt` and `rights.txt` is available via specific properties.
         - (core) Rows accessed trough this class have a `source_metadata` property that gives\
@@ -193,12 +224,12 @@ class GBIFResultsReader(DwCAReader):
     
     def __init__(self, path):
         super(GBIFResultsReader, self).__init__(path)
-        #: a dict containing source/original metadata of the archive, such as
+        #: A dict containing source/original metadata of the archive, such as
         #: {'dataset_uuid': 'dataset_metadata', ...}
         self.source_metadata = self._dataset_metadata_to_dict('dataset')
 
     def _dataset_metadata_to_dict(self, folder):
-        dataset_dir = os.path.join(self._unzipped_folder_path, folder)
+        dataset_dir = os.path.join(self._workin_directory_path, folder)
 
         r = {}
         for f in os.listdir(dataset_dir):
